@@ -111,6 +111,9 @@ setMethod("initialize", "propr",
             }
 
             # Quality control check input
+            # if(any(apply(counts, 2, function(x) all(x == 0)))){
+            #   stop("Remove components with all zeros before proceeding.")}
+            if(any(counts < 0)) stop("Data may not contain negative measurements.")
             if(any(is.na(counts))) stop("Remove NAs from 'counts' before proceeding.")
             if(class(counts) == "data.frame") counts <- as.matrix(counts)
             if(is.null(colnames(counts))) colnames(counts) <- as.character(1:ncol(counts))
