@@ -52,29 +52,123 @@ double wtvRcpp(NumericVector x,
 
 // Calculate lrm with or without weights
 // [[Rcpp::export]]
-NumericVector lrm(NumericMatrix & X,
+NumericVector lrm(NumericMatrix & Y,
                   NumericMatrix & W,
-                  bool weighted = false){
+                  bool weighted = false,
+                  double a = NA_REAL,
+                  NumericMatrix Yfull = NumericMatrix(1, 1),
+                  NumericMatrix Wfull = NumericMatrix(1, 1)){
 
+  // Output a half-matrix
+  NumericMatrix X = clone(Y);
   int nfeats = X.ncol();
   int llt = nfeats * (nfeats - 1) / 2;
-  Rcpp::NumericVector result(llt);
-  Rcpp::NumericVector Wij(nfeats);
+  NumericVector result(llt);
   int counter = 0;
 
-  if(weighted){
-    for(int i = 1; i < nfeats; i++){
-      for(int j = 0; j < i; j++){
-        Wij = W(_, i) * W(_, j);
-        result(counter) = wtmRcpp(log(X(_, i) / X(_, j)), Wij);
-        counter += 1;
+  if(!R_IsNA(a)){ // Weighted and non-weighted, alpha-transformed
+
+    //////////////////////////////////////////////////////
+    // Check for valid Yfull argument
+    if(Yfull.nrow() == NumericMatrix(1, 1).nrow() &&
+       Yfull.ncol() == NumericMatrix(1, 1).ncol()){
+
+      stop("User must provide valid Yfull argument for alpha-transformation.");
+    }
+
+    // Raise all of X to the a power
+    for(int i = 0; i < X.nrow(); i++){
+      for(int j = 0; j < X.ncol(); j++){
+        X(i, j) = pow(X(i, j), a);
       }
     }
-  }else{
-    for(int i = 1; i < nfeats; i++){
-      for(int j = 0; j < i; j++){
-        result(counter) = mean(log(X(_, i) / X(_, j)));
-        counter += 1;
+
+    // Raise all of Xfull to the a power
+    NumericMatrix Xfull = clone(Yfull);
+    int fullfeats = Xfull.ncol();
+    for(int i = 0; i < Xfull.nrow(); i++){
+      for(int j = 0; j < Xfull.ncol(); j++){
+        Xfull(i, j) = pow(Xfull(i, j), a);
+      }
+    }
+    //////////////////////////////////////////////////////
+
+    if(weighted){
+
+      //////////////////////////////////////////////////////
+      // Check for valid Wfull argument
+      if(Wfull.nrow() == NumericMatrix(1, 1).nrow() &&
+         Wfull.ncol() == NumericMatrix(1, 1).ncol()){
+
+        stop("User must provide valid Wfull argument for weighted alpha-transformation.");
+      }
+      //////////////////////////////////////////////////////
+
+      // Calculate alpha-transformed mean using the across-group means
+      Rcpp::NumericVector Wij(nfeats);
+      Rcpp::NumericVector Wfullij(fullfeats);
+      Rcpp::NumericVector Xiscaled(nfeats);
+      Rcpp::NumericVector Xjscaled(nfeats);
+      Rcpp::NumericVector Xz(nfeats);
+      Rcpp::NumericVector Xfullz(fullfeats);
+      for(int i = 1; i < nfeats; i++){
+        for(int j = 0; j < i; j++){
+          Wij = W(_, i) * W(_, j);
+          Wfullij = Wfull(_, i) * Wfull(_, j);
+          Xiscaled = X(_, i) / wtmRcpp(Xfull(_, i), Wfullij);
+          Xjscaled = X(_, j) / wtmRcpp(Xfull(_, j), Wfullij);
+          Xz = X(_, i) - X(_, j);
+          Xfullz = Xfull(_, i) - Xfull(_, j);
+          double Mz = sum(Wij * (Xiscaled - Xjscaled) / sum(Wij));
+          double Cz = sum(Wij * Xz) / sum(Wij) +
+            (sum(Wfullij * Xfullz) - sum(Wij * Xz)) /
+              (sum(Wfullij) - sum(Wij));
+          result(counter) = (Cz/2 + Mz) / a;
+          counter += 1;
+        }
+      }
+
+    }else{
+
+      // Calculate alpha-transformed mean using the across-group means
+      Rcpp::NumericVector Xz(nfeats);
+      Rcpp::NumericVector Xfullz(fullfeats);
+      double N1 = X.nrow();
+      double NT = Xfull.nrow();
+      for(int i = 1; i < nfeats; i++){
+        for(int j = 0; j < i; j++){
+          Xz = X(_, i) - X(_, j);
+          Xfullz = Xfull(_, i) - Xfull(_, j);
+          double Mz = mean(X(_, i) / mean(Xfull(_, i)) - mean(X(_, j) / mean(Xfull(_, j))));
+          double Cz = sum(Xz) / N1 +
+            (sum(Xfullz) - sum(Xz)) /
+              (NT - N1);
+          result(counter) = (Cz/2 + Mz) / a;
+          counter += 1;
+        }
+      }
+    }
+
+  }else{ // Weighted and non-weighted, non-transformed
+
+    if(weighted){
+
+      Rcpp::NumericVector Wij(nfeats);
+      for(int i = 1; i < nfeats; i++){
+        for(int j = 0; j < i; j++){
+          Wij = W(_, i) * W(_, j);
+          result(counter) = wtmRcpp(log(X(_, i) / X(_, j)), Wij);
+          counter += 1;
+        }
+      }
+
+    }else{
+
+      for(int i = 1; i < nfeats; i++){
+        for(int j = 0; j < i; j++){
+          result(counter) = mean(log(X(_, i) / X(_, j)));
+          counter += 1;
+        }
       }
     }
   }
@@ -87,7 +181,9 @@ NumericVector lrm(NumericMatrix & X,
 NumericVector lrv(NumericMatrix & Y,
                   NumericMatrix & W,
                   bool weighted = false,
-                  double a = NA_REAL){
+                  double a = NA_REAL,
+                  NumericMatrix Yfull = NumericMatrix(1, 1),
+                  NumericMatrix Wfull = NumericMatrix(1, 1)){
 
   // Output a half-matrix
   NumericMatrix X = clone(Y);
@@ -98,6 +194,14 @@ NumericVector lrv(NumericMatrix & Y,
 
   if(!R_IsNA(a)){ // Weighted and non-weighted, alpha-transformed
 
+    //////////////////////////////////////////////////////
+    // Check for valid Yfull argument
+    if(Yfull.nrow() == NumericMatrix(1, 1).nrow() &&
+       Yfull.ncol() == NumericMatrix(1, 1).ncol()){
+
+      stop("User must provide valid Yfull argument for alpha-transformation.");
+    }
+
     // Raise all of X to the a power
     for(int i = 0; i < X.nrow(); i++){
       for(int j = 0; j < X.ncol(); j++){
@@ -105,21 +209,41 @@ NumericVector lrv(NumericMatrix & Y,
       }
     }
 
+    // Raise all of Xfull to the a power
+    NumericMatrix Xfull = clone(Yfull);
+    int fullfeats = Xfull.ncol();
+    for(int i = 0; i < Xfull.nrow(); i++){
+      for(int j = 0; j < Xfull.ncol(); j++){
+        Xfull(i, j) = pow(Xfull(i, j), a);
+      }
+    }
+    //////////////////////////////////////////////////////
+
     if(weighted){
 
-      // Sweep out (weighted) column means
+      //////////////////////////////////////////////////////
+      // Check for valid Wfull argument
+      if(Wfull.nrow() == NumericMatrix(1, 1).nrow() &&
+         Wfull.ncol() == NumericMatrix(1, 1).ncol()){
+
+        stop("User must provide valid Wfull argument for weighted alpha-transformation.");
+      }
+      //////////////////////////////////////////////////////
+
+      // Mean-center the within-group values as a fraction of the across-group means
       // Calculate sum(W * [i - j]^2)
       // Divide sum(W * [i - j]^2) by (p * a^2)
       Rcpp::NumericVector Wij(nfeats);
+      Rcpp::NumericVector Wfullij(fullfeats);
       Rcpp::NumericVector Xiscaled(nfeats);
       Rcpp::NumericVector Xjscaled(nfeats);
       for(int i = 1; i < nfeats; i++){
         for(int j = 0; j < i; j++){
           Wij = W(_, i) * W(_, j);
-          Xiscaled = X(_, i) / wtmRcpp(X(_, i), Wij);
-          Xjscaled = X(_, j) / wtmRcpp(X(_, j), Wij);
-          result(counter) = sum(Wij * pow(Xiscaled - Xjscaled, 2));
-          result(counter) = result(counter) /
+          Wfullij = Wfull(_, i) * Wfull(_, j);
+          Xiscaled = (X(_, i) - wtmRcpp(X(_, i), Wij)) / wtmRcpp(Xfull(_, i), Wfullij);
+          Xjscaled = (X(_, j) - wtmRcpp(X(_, j), Wij)) / wtmRcpp(Xfull(_, j), Wfullij);
+          result(counter) = sum(Wij * pow(Xiscaled - Xjscaled, 2)) /
             (pow(a, 2) * (sum(Wij) - sum(pow(Wij, 2)) / sum(Wij)));
           counter += 1;
         }
@@ -127,24 +251,23 @@ NumericVector lrv(NumericMatrix & Y,
 
     }else{
 
-      // Sweep out column means
-      for(int j = 0; j < X.ncol(); j++){
-        X(_, j) = X(_, j) / mean(X(_, j));
-      }
-
+      // Mean-center the within-group values as a fraction of the across-group means
       // Calculate sum([i - j]^2)
       // Divide sum([i - j]^2) by ((N-1) * a^2)
+      Rcpp::NumericVector Xiscaled(nfeats);
+      Rcpp::NumericVector Xjscaled(nfeats);
+      double N1 = X.nrow();
       for(int i = 1; i < nfeats; i++){
         for(int j = 0; j < i; j++){
-          result(counter) = sum(pow(X(_, i) - X(_, j), 2));
-          result(counter) = result(counter) /
-            (pow(a, 2) * (X.nrow() - 1));
+          Xiscaled = (X(_, i) - mean(X(_, i))) / mean(Xfull(_, i));
+          Xjscaled = (X(_, j) - mean(X(_, j))) / mean(Xfull(_, j));
+          result(counter) = sum(pow(Xiscaled - Xjscaled, 2)) /
+            (pow(a, 2) * (N1 - 1));
           counter += 1;
         }
       }
     }
 
-
   }else{ // Weighted and non-weighted, non-transformed
 
     if(weighted){
@@ -195,89 +318,3 @@ NumericVector omega(NumericMatrix & X,
 
   return result;
 }
-
-// Calculate lrv w.r.t. z
-// [[Rcpp::export]]
-NumericVector lrz(NumericMatrix & Y,
-                  NumericMatrix & W,
-                  NumericVector & Z,
-                  bool weighted = false,
-                  double a = NA_REAL){
-
-  // Output a half-matrix
-  NumericMatrix X = clone(Y);
-  NumericVector z = clone(Z);
-  int nfeats = X.ncol();
-  int nsamps = X.nrow();
-  NumericVector result(nfeats);
-  int counter = 0;
-
-  if(!R_IsNA(a)){ // Weighted and non-weighted, alpha-transformed
-
-    // Raise all of X and z to the a power
-    for(int i = 0; i < nsamps; i++){
-      z(i) = pow(Z(i), a);
-      for(int j = 0; j < nfeats; j++){
-        X(i, j) = pow(X(i, j), a);
-      }
-    }
-
-    if(weighted){
-
-      // Sweep out (weighted) column means
-      // Calculate sum(W * [i - j]^2)
-      // Divide sum(W * [i - j]^2) by (p * a^2)
-      Rcpp::NumericVector Wij(nfeats);
-      Rcpp::NumericVector Xiscaled(nfeats);
-      Rcpp::NumericVector Xjscaled(nfeats);
-      for(int j = 0; j < nfeats; j++){
-        Wij = W(_, j);
-        Xiscaled = X(_, j) / wtmRcpp(X(_, j), Wij);
-        Xjscaled = z / wtmRcpp(z, Wij);
-        result(counter) = sum(Wij * pow(Xiscaled - Xjscaled, 2));
-        result(counter) = result(counter) /
-          (pow(a, 2) * (sum(Wij) - sum(pow(Wij, 2)) / sum(Wij)));
-        counter += 1;
-      }
-
-    }else{
-
-      // Sweep out column means
-      z = z / mean(z);
-      for(int j = 0; j < nfeats; j++){
-        X(_, j) = X(_, j) / mean(X(_, j));
-      }
-
-      // Calculate sum([i - j]^2)
-      // Divide sum([i - j]^2) by ((N-1) * a^2)
-      for(int j = 0; j < nfeats; j++){
-        result(counter) = sum(pow(X(_, j) - z, 2));
-        result(counter) = result(counter) /
-          (pow(a, 2) * (X.nrow() - 1));
-        counter += 1;
-      }
-    }
-
-
-  }else{ // Weighted and non-weighted, non-transformed
-
-    if(weighted){
-
-      Rcpp::NumericVector Wij(nfeats);
-      for(int j = 0; j < nfeats; j++){
-        Wij = W(_, j);
-        result(counter) = wtvRcpp(log(X(_, j) / z), Wij);
-        counter += 1;
-      }
-
-    }else{
-
-      for(int j = 0; j < nfeats; j++){
-        result(counter) = var(log(X(_, j) / z));
-        counter += 1;
-      }
-    }
-  }
-
-  return result;
-}
